Exception: Mysigner::Upload::PlayStoreUploader::PartialUploadError
- Inherits:
-
UploadError
- Object
- StandardError
- Error
- UploadError
- Mysigner::Upload::PlayStoreUploader::PartialUploadError
- Defined in:
- lib/mysigner/upload/play_store_uploader.rb
Overview
Special error for when AAB uploaded but track assignment failed This carries the version_code so it can be saved to prevent conflicts
Instance Attribute Summary collapse
-
#version_code ⇒ Object
readonly
Returns the value of attribute version_code.
Instance Method Summary collapse
-
#initialize(message, version_code:) ⇒ PartialUploadError
constructor
A new instance of PartialUploadError.
Constructor Details
#initialize(message, version_code:) ⇒ PartialUploadError
Returns a new instance of PartialUploadError.
17 18 19 20 |
# File 'lib/mysigner/upload/play_store_uploader.rb', line 17 def initialize(, version_code:) super() @version_code = version_code end |
Instance Attribute Details
#version_code ⇒ Object (readonly)
Returns the value of attribute version_code.
15 16 17 |
# File 'lib/mysigner/upload/play_store_uploader.rb', line 15 def version_code @version_code end |